@@ -23,6 +23,14 @@
 #include <gio/gunixinputstream.h>
 #include <gio/gunixoutputstream.h>
 
+#ifdef __OpenBSD__
+#include <sys/param.h>
+#include <sys/proc.h>
+#include <sys/sysctl.h>
+#include <fcntl.h>
+#include <kvm.h>
+#endif
+
 #include "tracker-dbus.h"
 #include "tracker-log.h"
 
@@ -139,6 +147,7 @@ client_data_new (gchar *sender)
 	}
 
 	if (get_binary) {
+#ifndef __OpenBSD__
 		gchar *filename;
 		gchar *pid_str;
 		gchar *contents = NULL;
@@ -171,6 +180,36 @@ client_data_new (gchar *sender)
 
 		g_strfreev (strv);
 		g_free (contents);
+#else
+		gint nproc;
+		struct kinfo_proc *kp;
+		kvm_t *kd;
+		gchar **strv;
+
+		if ((kd = kvm_openfiles (NULL, NULL, NULL, KVM_NO_FILES, NULL)) == NULL)
+			return cd;
+
+		if ((kp = kvm_getprocs (kd, KERN_PROC_PID, cd->pid, sizeof (*kp), &nproc)) == NULL) {
+			g_warning ("Could not get process name: %s", kvm_geterr (kd));
+			kvm_close(kd);
+			return cd;
+		}
+
+		if ((kp->p_flag & P_SYSTEM) != 0) {
+			kvm_close(kd);
+			return cd;
+		}
+
+		strv = kvm_getargv (kd, kp, 0);
+
+		if (strv == NULL) {
+			kvm_close(kd);
+			return cd;
+		} else {
+			cd->binary = g_path_get_basename (strv[0]);
+			kvm_close(kd);
+		}
+#endif
 	}
 
 	return cd;
