@@ -26,6 +26,11 @@
 #include <unistd.h>
 #include <sys/resource.h>
 
+#if defined (__OpenBSD__)
+#include <sys/param.h>
+#include <sys/sysctl.h>
+#endif
+
 #include <glib.h>
 
 #include "tracker-log.h"
@@ -225,6 +230,7 @@ tracker_create_permission_string (struct stat finfo)
 static glong
 get_memory_total (void)
 {
+#if !defined (__OpenBSD__)
 	GError      *error = NULL;
 	const gchar *filename;
 	gchar       *contents = NULL;
@@ -258,6 +264,20 @@ get_memory_total (void)
 		}
 		g_free (contents);
 	}
+#else /* OpenBSD */
+	glong total = 0;
+	int64_t physmem;
+	size_t len;
+	static gint mib[] = { CTL_HW, HW_PHYSMEM64 };
+
+	len = sizeof (physmem);
+
+	if (sysctl (mib, G_N_ELEMENTS (mib), &physmem, &len, NULL, 0) == -1) {
+		g_critical ("Couldn't get memory information: %d", errno);
+	} else {
+		total = physmem;
+	}
+#endif /* !OpenBSD */
 
 	return total;
 }
