@@ -46,6 +46,7 @@
 #include "tracker-db-manager.h"
 #include "tracker-db-interface-sqlite.h"
 #include "tracker-db-interface.h"
+#include "tracker-data-manager.h"
 
 /* ZLib buffer settings */
 #define ZLIB_BUF_SIZE                 8192
@@ -168,11 +169,7 @@ static GStaticPrivate        interface_data_key = G_STATIC_PRIVATE_INIT;
 #endif
 
 /* mutex used by singleton connection in libtracker-direct, not used by tracker-store */
-#if GLIB_CHECK_VERSION (2,31,0)
 static GMutex                global_mutex;
-#else
-static GStaticMutex          global_mutex = G_STATIC_MUTEX_INIT;
-#endif
 
 static TrackerDBInterface   *global_iface;
 
@@ -1807,29 +1804,17 @@ tracker_db_manager_set_need_mtime_check (gboolean needed)
 void
 tracker_db_manager_lock (void)
 {
-#if GLIB_CHECK_VERSION (2,31,0)
 	g_mutex_lock (&global_mutex);
-#else
-	g_static_mutex_lock (&global_mutex);
-#endif
 }
 
 gboolean
 tracker_db_manager_trylock (void)
 {
-#if GLIB_CHECK_VERSION (2,31,0)
 	return g_mutex_trylock (&global_mutex);
-#else
-	return g_static_mutex_trylock (&global_mutex);
-#endif
 }
 
 void
 tracker_db_manager_unlock (void)
 {
-#if GLIB_CHECK_VERSION (2,31,0)
 	g_mutex_unlock (&global_mutex);
-#else
-	g_static_mutex_unlock (&global_mutex);
-#endif
 }
